# paleo

Python package for interfacing with CAVE edit histories

## Installation

Install via pip:

```bash
pip install paleo
```

Install via pip with optional dependencies:

```bash
pip install paleo[skeleton]
```
